package com.hrsk.cloud.eg.app.threedocking.impl;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.hrsk.cloud.eg.app.constant.ServerCodeEnums;
import com.hrsk.cloud.eg.app.threedocking.LoanDockingApi;
import com.hrsk.cloud.eg.dto.data.egPlan.PlanDto;
import com.hrsk.cloud.eg.dto.data.user.UserBaseInfoDto;
import com.hrsk.cloud.eg.infrastructure.config.client.config.RetryRestTemplate;
import com.hrsk.cloud.eg.infrastructure.repository.database.entity.ProductBusinessApiInfoDo;
import com.hrsk.cloud.eg.infrastructure.service.ProductBusinessApiInfoService;
import com.hrsk.cloud.eg.infrastructure.utils.Md5Util;
import com.hrsk.cloud.eg.vo.response.DataVo;
import lombok.Data;
import lombok.extern.slf4j.Slf4j;
import org.apache.http.HttpResponse;
import org.apache.http.util.EntityUtils;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.HashMap;
import java.util.Map;

/**
 * @Author Liu Tao
 * @Date 2024 07 17 15 21
 **/
@Slf4j
@Component
public class ShenLuoJinFuCreditService implements LoanDockingApi {
    @Resource
    private ProductBusinessApiInfoService apiInfoService;

    @Resource
    private RetryRestTemplate httpRestTemplate;
    @Override
    public ServerCodeEnums getType() {
        return ServerCodeEnums.ShenLuoJinFu;
    }

    @Data
    private static class CheckInfo{
        private String account_key;//account_key值需接口方提供
        private String tel_m;//手机号（MD5加密的32位小写）
        private String city;//城市，例如（上海或上海市）
        private String repeat_system;//指定系统撞库（需接口方提供）
    }




    @Override
    public DataVo qualityCheck(UserBaseInfoDto userInfo, PlanDto product) {
        try {
            ProductBusinessApiInfoDo apiInfo = apiInfoService.getById(product.getApiId());
            String configJson = apiInfo.getThreeSystemConfig();
            JSONObject config = JSONObject.parseObject(configJson);
            log.info("盛略金服对接参数:{}", JSON.toJSONString(config));
            CheckInfo checkInfo = new CheckInfo();
            String phoneMd5 = userInfo.getPhoneMd5() == null ? Md5Util.encoderByMd5(userInfo.getUserMobile()) : userInfo.getPhoneMd5();
            Map<String, String> requestData = new HashMap<>();
            requestData.put("tel_m", phoneMd5);
            requestData.put("account_key", config.getString("account_key"));
            requestData.put("city",userInfo.getCityAllName());
            if (config.getString("repeat_system")!=null){
                requestData.put("repeat_system", config.getString("repeat_system"));
            }
            String url = config.getString("checkUrl");
            log.info("credit qualityCheck ShenLuoJinFuCreditService request userId:{}, url:{}, CheckInfo:{}",userInfo.getUserId(), url, checkInfo);
            JSONObject response = null;
            try{
                Map<String, String> head = new HashMap<>();
                head.put("Content-Type", "application/x-www-form-urlencoded");
                HttpResponse httpResponse = httpRestTemplate.restTemplate().postForObject(url, null, null, head, null, requestData);
                String responseStr = EntityUtils.toString(httpResponse.getEntity());
                response = JSONObject.parseObject(responseStr);
            }catch (Exception e){
                log.error("盛略金服准入异常,异常信息：{}", e.getMessage(), e);
            }
            log.info("credit qualityCheck ShenLuoJinFuCreditService response userId:{}, result:{}",userInfo.getUserId(), response);
            if (response == null) {
                return DataVo.timeout(product.getPlanId(), product.getPlanName());
            }
            if (response.getInteger("code")==1) {
                return DataVo.success(0, "盛略金服撞库成功", product.getPlanId());
            } else {
                return DataVo.fail(1, "盛略金服撞库失败，请联系系统管理员", product.getPlanId());
            }
        } catch (Exception e) {
            log.error("盛略金服撞库失败", e);
            return DataVo.fail(1, "盛略金服撞库失败，请联系系统管理员", product.getPlanId());
        }

    }


}
